# COMSYL - COherent Modes for SYnchrotron Light

COMSYL makes the coherent mode decomposition of synchrotron radiation emitted by electrons passing through an undulator placed in a storage ring. COMSYL permits naturally the statistical analysis and propagation of the cross spectral density along the beamline optics. The coherence properties of the X-ray beam at any point of the beamline are completely given in terms of the eigenvalues and coherent modes of the cross spectral density.

An example of coherent mode decomposition of undulator radiation (U18 1.4m long undulator at resonance 17225 eV)  at the ESRF-EBS calculated with COMSYL is here: https://youtu.be/h24RrJZaQ80

References: 
----------

- Coherent modes of X-ray beams emitted by undulators in new storage rings

  Mark Glass and Manuel Sanchez del Rio
  
  EPL, 119 3 (2017) 34004
  
  DOI: https://doi.org/10.1209/0295-5075/119/34004
  
  Free preprint:  https://arxiv.org/abs/1706.04393

- PhD Dissertation: 
  
  Mark Glass
  
  Statistical optics for synchrotron emission: numerical calculation of coherent modes
  
  https://tel.archives-ouvertes.fr/tel-01664052

See the Wiki pages https://github.com/mark-glass/comsyl/wiki for more information
